import { IEventParam, Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { LoadingService, DialogService, Button } from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';

export class CrmClassificacaoDeOportunidadeController {
  public addNewRow({ component }: IEventParam<TekGrid>) {
    const newId = 0;
    component.addNewRow({ NRSEQCLASSOPORT: newId, IDATIVO: 'S' }, 'start');
  }

  public openFilter({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(
      `${component.name}_filterButton`,
    );
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public saveSortOfOpportunity({ component, event }: IEventParam<TekGrid>) {
    event!.preventDefault();
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/saveSortOfOpportunity', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public dialogdeleteSortOfOpportunity({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmClassificacaoDeOportunidadeController.deleteSortOfOpportunity');
  }

  public deleteSortOfOpportunity() {
    const grid = Metadata.getInstance<TekGrid>('tek-grid-crm_classificacao_de_oportunidade_grid');
    LoadingService.show();
    Http.post('/deleteSortOfOpportunity', {
      NRSQ: (grid.selectedRows.map((element: any) => element.NRSEQCLASSOPORT)),
    }).then(() => {
      grid.datasource.get();
      Utilities.showSuccessMessage();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
