import { IEventParam, Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';
import { Button, LoadingService, DialogService } from '@zeedhi/common';

export class CrmRamodeAtividadeController {
  public addNewRow({ component }: IEventParam<TekGrid>) {
    const newId = 0;
    component.addNewRow({ CDATIVCLI: newId, IDATIVO: 'S' }, 'start');
  }

  public saveNewBranch({ component, event }: IEventParam<TekGrid>) {
    event!.preventDefault();
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/saveNewBranch', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public reloadGrid(grid: any) {
    const filterButton = Metadata.getInstance<Button>(`${grid}_refreshButton`);
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public openFilter({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(
      `${component.name}_filterButton`,
    );
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public canEditRow({ row }: any) {
    return row['.__added_row'] === true;
  }

  public messageDeleteBranch({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmRamodeAtividadeController.deleteBranchOfActivity');
  }

  public deleteBranchOfActivity() {
    const component = Metadata.getInstance<TekGrid>('tek_grid_crm_ramo_de_atividade_grid');
    LoadingService.show();
    Http.post('/deleteBranchOfActivity', {
      CDAT: component.selectedRows.map((element: any) => element.CDATIVCLI),
    }).then(() => {
      Utilities.showSuccessMessage();
      component.datasource.get();
    }).catch((error: any) => {
      error.showErrorMessage();
    }).finally(() => {
      component.selectedRows = [];
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
